@@ -1,7 +1,6 @@
 use super::*;
 use swc_common::{sync::Lrc, FilePathMapping};
-use swc_ecma_transforms_testing::test;
-use swc_ecma_transforms_testing::test_exec;
+use swc_ecma_transforms_testing::{test, test_exec};
 
 fn tr() -> impl Fold {
     let cm = Lrc::new(SourceMap::new(FilePathMapping::empty()));
